@@ -2,79 +2,81 @@ info = {
     "name": "az-Latn",
     "date_order": "DMY",
     "january": [
-        "yanvar",
-        "yan"
+        "yan",
+        "yanvar"
     ],
     "february": [
-        "fevral",
-        "fev"
+        "fev",
+        "fevral"
     ],
     "march": [
-        "mart",
-        "mar"
+        "mar",
+        "mart"
     ],
     "april": [
-        "aprel",
-        "apr"
+        "apr",
+        "aprel"
     ],
     "may": [
         "may"
     ],
     "june": [
+        "iyn",
         "iyun",
-        "iyn"
+        "i̇yun"
     ],
     "july": [
+        "iyl",
         "iyul",
-        "iyl"
+        "i̇yul"
     ],
     "august": [
-        "avqust",
-        "avq"
+        "avq",
+        "avqust"
     ],
     "september": [
-        "sentyabr",
-        "sen"
+        "sen",
+        "sentyabr"
     ],
     "october": [
-        "oktyabr",
-        "okt"
+        "okt",
+        "oktyabr"
     ],
     "november": [
-        "noyabr",
-        "noy"
+        "noy",
+        "noyabr"
     ],
     "december": [
-        "dekabr",
-        "dek"
+        "dek",
+        "dekabr"
     ],
     "monday": [
         "bazar ertəsi",
         "be"
     ],
     "tuesday": [
-        "çərşənbə axşamı",
-        "ça"
+        "ça",
+        "çərşənbə axşamı"
     ],
     "wednesday": [
-        "çərşənbə",
-        "ç"
+        "ç",
+        "çərşənbə"
     ],
     "thursday": [
-        "cümə axşamı",
-        "ca"
+        "ca",
+        "cümə axşamı"
     ],
     "friday": [
-        "cümə",
-        "c"
+        "c",
+        "cümə"
     ],
     "saturday": [
-        "şənbə",
-        "ş"
+        "ş",
+        "şənbə"
     ],
     "sunday": [
-        "bazar",
-        "b"
+        "b",
+        "bazar"
     ],
     "am": [
         "am"
@@ -83,7 +85,8 @@ info = {
         "pm"
     ],
     "year": [
-        "il"
+        "il",
+        "i̇l"
     ],
     "month": [
         "ay"
@@ -98,117 +101,117 @@ info = {
         "saat"
     ],
     "minute": [
-        "dəqiqə",
-        "dəq"
+        "dəq",
+        "dəqiqə"
     ],
     "second": [
-        "saniyə",
-        "san"
+        "san",
+        "saniyə"
     ],
     "relative-type": {
-        "1 year ago": [
-            "keçən il"
-        ],
-        "0 year ago": [
-            "bu il"
-        ],
-        "in 1 year": [
-            "gələn il"
-        ],
-        "1 month ago": [
-            "keçən ay"
-        ],
-        "0 month ago": [
-            "bu ay"
-        ],
-        "in 1 month": [
-            "gələn ay"
-        ],
-        "1 week ago": [
-            "keçən həftə"
-        ],
-        "0 week ago": [
-            "bu həftə"
-        ],
-        "in 1 week": [
-            "gələn həftə"
-        ],
-        "1 day ago": [
-            "dünən"
-        ],
         "0 day ago": [
             "bu gün"
         ],
-        "in 1 day": [
-            "sabah"
-        ],
         "0 hour ago": [
             "bu saat"
         ],
         "0 minute ago": [
             "bu dəqiqə"
         ],
+        "0 month ago": [
+            "bu ay"
+        ],
         "0 second ago": [
             "indi"
+        ],
+        "0 week ago": [
+            "bu həftə"
+        ],
+        "0 year ago": [
+            "bu il"
+        ],
+        "1 day ago": [
+            "dünən"
+        ],
+        "1 month ago": [
+            "keçən ay"
+        ],
+        "1 week ago": [
+            "keçən həftə"
+        ],
+        "1 year ago": [
+            "keçən il"
+        ],
+        "in 1 day": [
+            "sabah"
+        ],
+        "in 1 month": [
+            "gələn ay"
+        ],
+        "in 1 week": [
+            "gələn həftə"
+        ],
+        "in 1 year": [
+            "gələn il"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+) il ərzində"
-        ],
-        "\\1 year ago": [
-            "(\\d+) il öncə"
-        ],
-        "in \\1 month": [
-            "(\\d+) ay ərzində"
-        ],
-        "\\1 month ago": [
-            "(\\d+) ay öncə"
-        ],
-        "in \\1 week": [
-            "(\\d+) həftə ərzində"
-        ],
-        "\\1 week ago": [
-            "(\\d+) həftə öncə"
-        ],
-        "in \\1 day": [
-            "(\\d+) gün ərzində"
-        ],
         "\\1 day ago": [
-            "(\\d+) gün öncə"
-        ],
-        "in \\1 hour": [
-            "(\\d+) saat ərzində"
+            "(\\d+[.,]?\\d*) gün öncə"
         ],
         "\\1 hour ago": [
-            "(\\d+) saat öncə"
-        ],
-        "in \\1 minute": [
-            "(\\d+) dəqiqə ərzində"
+            "(\\d+[.,]?\\d*) saat öncə"
         ],
         "\\1 minute ago": [
-            "(\\d+) dəqiqə öncə"
+            "(\\d+[.,]?\\d*) dəqiqə öncə"
         ],
-        "in \\1 second": [
-            "(\\d+) saniyə ərzində"
+        "\\1 month ago": [
+            "(\\d+[.,]?\\d*) ay öncə"
         ],
         "\\1 second ago": [
-            "(\\d+) saniyə öncə"
+            "(\\d+[.,]?\\d*) saniyə öncə"
+        ],
+        "\\1 week ago": [
+            "(\\d+[.,]?\\d*) həftə öncə"
+        ],
+        "\\1 year ago": [
+            "(\\d+[.,]?\\d*) il öncə"
+        ],
+        "in \\1 day": [
+            "(\\d+[.,]?\\d*) gün ərzində"
+        ],
+        "in \\1 hour": [
+            "(\\d+[.,]?\\d*) saat ərzində"
+        ],
+        "in \\1 minute": [
+            "(\\d+[.,]?\\d*) dəqiqə ərzində"
+        ],
+        "in \\1 month": [
+            "(\\d+[.,]?\\d*) ay ərzində"
+        ],
+        "in \\1 second": [
+            "(\\d+[.,]?\\d*) saniyə ərzində"
+        ],
+        "in \\1 week": [
+            "(\\d+[.,]?\\d*) həftə ərzində"
+        ],
+        "in \\1 year": [
+            "(\\d+[.,]?\\d*) il ərzində"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
