@@ -2,24 +2,24 @@ info = {
     "name": "bez",
     "date_order": "DMY",
     "january": [
-        "pa mwedzi gwa hutala",
-        "hut"
+        "hut",
+        "pa mwedzi gwa hutala"
     ],
     "february": [
         "pa mwedzi gwa wuvili",
         "vil"
     ],
     "march": [
-        "pa mwedzi gwa wudatu",
-        "dat"
+        "dat",
+        "pa mwedzi gwa wudatu"
     ],
     "april": [
         "pa mwedzi gwa wutai",
         "tai"
     ],
     "may": [
-        "pa mwedzi gwa wuhanu",
-        "han"
+        "han",
+        "pa mwedzi gwa wuhanu"
     ],
     "june": [
         "pa mwedzi gwa sita",
@@ -30,52 +30,52 @@ info = {
         "sab"
     ],
     "august": [
-        "pa mwedzi gwa nane",
-        "nan"
+        "nan",
+        "pa mwedzi gwa nane"
     ],
     "september": [
         "pa mwedzi gwa tisa",
         "tis"
     ],
     "october": [
-        "pa mwedzi gwa kumi",
-        "kum"
+        "kum",
+        "pa mwedzi gwa kumi"
     ],
     "november": [
-        "pa mwedzi gwa kumi na moja",
-        "kmj"
+        "kmj",
+        "pa mwedzi gwa kumi na moja"
     ],
     "december": [
-        "pa mwedzi gwa kumi na mbili",
-        "kmb"
+        "kmb",
+        "pa mwedzi gwa kumi na mbili"
     ],
     "monday": [
         "pa shahuviluha",
         "vil"
     ],
     "tuesday": [
-        "pa hivili",
-        "hiv"
+        "hiv",
+        "pa hivili"
     ],
     "wednesday": [
-        "pa hidatu",
-        "hid"
+        "hid",
+        "pa hidatu"
     ],
     "thursday": [
-        "pa hitayi",
-        "hit"
+        "hit",
+        "pa hitayi"
     ],
     "friday": [
-        "pa hihanu",
-        "hih"
+        "hih",
+        "pa hihanu"
     ],
     "saturday": [
-        "pa shahulembela",
-        "lem"
+        "lem",
+        "pa shahulembela"
     ],
     "sunday": [
-        "pa mulungu",
-        "mul"
+        "mul",
+        "pa mulungu"
     ],
     "am": [
         "pamilau"
@@ -105,65 +105,65 @@ info = {
         "sekunde"
     ],
     "relative-type": {
-        "1 year ago": [
-            "last year"
-        ],
-        "0 year ago": [
-            "this year"
-        ],
-        "in 1 year": [
-            "next year"
-        ],
-        "1 month ago": [
-            "last month"
-        ],
-        "0 month ago": [
-            "this month"
-        ],
-        "in 1 month": [
-            "next month"
-        ],
-        "1 week ago": [
-            "last week"
-        ],
-        "0 week ago": [
-            "this week"
-        ],
-        "in 1 week": [
-            "next week"
-        ],
-        "1 day ago": [
-            "igolo"
-        ],
         "0 day ago": [
             "neng'u ni"
         ],
-        "in 1 day": [
-            "hilawu"
-        ],
         "0 hour ago": [
             "this hour"
         ],
         "0 minute ago": [
             "this minute"
         ],
+        "0 month ago": [
+            "this month"
+        ],
         "0 second ago": [
             "now"
+        ],
+        "0 week ago": [
+            "this week"
+        ],
+        "0 year ago": [
+            "this year"
+        ],
+        "1 day ago": [
+            "igolo"
+        ],
+        "1 month ago": [
+            "last month"
+        ],
+        "1 week ago": [
+            "last week"
+        ],
+        "1 year ago": [
+            "last year"
+        ],
+        "in 1 day": [
+            "hilawu"
+        ],
+        "in 1 month": [
+            "next month"
+        ],
+        "in 1 week": [
+            "next week"
+        ],
+        "in 1 year": [
+            "next year"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
