@@ -134,40 +134,40 @@ info = {
     },
     "relative-type-regex": {
         "\\1 day ago": [
-            "ɛ́ gɛ́ mɔ́ lɛ́ꞌ (\\d+)"
+            "ɛ́ gɛ́ mɔ́ lɛ́ꞌ (\\d+[.,]?\\d*)"
         ],
         "\\1 hour ago": [
-            "ɛ́ gɛ mɔ́ (\\d+) háwa"
+            "ɛ́ gɛ mɔ́ (\\d+[.,]?\\d*) háwa"
         ],
         "\\1 minute ago": [
-            "ɛ́ gɛ́ mɔ́ minút (\\d+)"
+            "ɛ́ gɛ́ mɔ́ minút (\\d+[.,]?\\d*)"
         ],
         "\\1 month ago": [
-            "ɛ́ gɛ́ mɔ́ pɛsaŋ (\\d+)"
+            "ɛ́ gɛ́ mɔ́ pɛsaŋ (\\d+[.,]?\\d*)"
         ],
         "\\1 week ago": [
-            "ɛ́ gɛ́ mɔ (\\d+) ŋgap-mbi"
+            "ɛ́ gɛ́ mɔ (\\d+[.,]?\\d*) ŋgap-mbi"
         ],
         "\\1 year ago": [
-            "ɛ́gɛ́ mɔ́ ŋguꞌ (\\d+)"
+            "ɛ́gɛ́ mɔ́ ŋguꞌ (\\d+[.,]?\\d*)"
         ],
         "in \\1 day": [
-            "nǔu lɛ́ꞌ (\\d+)"
+            "nǔu lɛ́ꞌ (\\d+[.,]?\\d*)"
         ],
         "in \\1 hour": [
-            "nǔu háwa (\\d+)"
+            "nǔu háwa (\\d+[.,]?\\d*)"
         ],
         "in \\1 minute": [
-            "nǔu (\\d+) minút"
+            "nǔu (\\d+[.,]?\\d*) minút"
         ],
         "in \\1 month": [
-            "nǔu (\\d+) saŋ"
+            "nǔu (\\d+[.,]?\\d*) saŋ"
         ],
         "in \\1 week": [
-            "nǔu ŋgap-mbi (\\d+)"
+            "nǔu ŋgap-mbi (\\d+[.,]?\\d*)"
         ],
         "in \\1 year": [
-            "nǔu ŋguꞌ (\\d+)"
+            "nǔu ŋguꞌ (\\d+[.,]?\\d*)"
         ]
     },
     "locale_specific": {},
