@@ -151,56 +151,56 @@ info = {
     },
     "relative-type-regex": {
         "\\1 day ago": [
-            "(\\d+) ਦਿਨ ਪਹਿਲਾਂ"
+            "(\\d+[.,]?\\d*) ਦਿਨ ਪਹਿਲਾਂ"
         ],
         "\\1 hour ago": [
-            "(\\d+) ਘੰਟਾ ਪਹਿਲਾਂ",
-            "(\\d+) ਘੰਟੇ ਪਹਿਲਾਂ"
+            "(\\d+[.,]?\\d*) ਘੰਟਾ ਪਹਿਲਾਂ",
+            "(\\d+[.,]?\\d*) ਘੰਟੇ ਪਹਿਲਾਂ"
         ],
         "\\1 minute ago": [
-            "(\\d+) ਮਿੰਟ ਪਹਿਲਾਂ"
+            "(\\d+[.,]?\\d*) ਮਿੰਟ ਪਹਿਲਾਂ"
         ],
         "\\1 month ago": [
-            "(\\d+) ਮਹੀਨਾ ਪਹਿਲਾਂ",
-            "(\\d+) ਮਹੀਨੇ ਪਹਿਲਾਂ"
+            "(\\d+[.,]?\\d*) ਮਹੀਨਾ ਪਹਿਲਾਂ",
+            "(\\d+[.,]?\\d*) ਮਹੀਨੇ ਪਹਿਲਾਂ"
         ],
         "\\1 second ago": [
-            "(\\d+) ਸਕਿੰਟ ਪਹਿਲਾਂ"
+            "(\\d+[.,]?\\d*) ਸਕਿੰਟ ਪਹਿਲਾਂ"
         ],
         "\\1 week ago": [
-            "(\\d+) ਹਫ਼ਤਾ ਪਹਿਲਾਂ",
-            "(\\d+) ਹਫ਼ਤੇ ਪਹਿਲਾਂ"
+            "(\\d+[.,]?\\d*) ਹਫ਼ਤਾ ਪਹਿਲਾਂ",
+            "(\\d+[.,]?\\d*) ਹਫ਼ਤੇ ਪਹਿਲਾਂ"
         ],
         "\\1 year ago": [
-            "(\\d+) ਸਾਲ ਪਹਿਲਾਂ"
+            "(\\d+[.,]?\\d*) ਸਾਲ ਪਹਿਲਾਂ"
         ],
         "in \\1 day": [
-            "(\\d+) ਦਿਨ ਵਿੱਚ",
-            "(\\d+) ਦਿਨਾਂ ਵਿੱਚ"
+            "(\\d+[.,]?\\d*) ਦਿਨ ਵਿੱਚ",
+            "(\\d+[.,]?\\d*) ਦਿਨਾਂ ਵਿੱਚ"
         ],
         "in \\1 hour": [
-            "(\\d+) ਘੰਟਿਆਂ ਵਿੱਚ",
-            "(\\d+) ਘੰਟੇ ਵਿੱਚ"
+            "(\\d+[.,]?\\d*) ਘੰਟਿਆਂ ਵਿੱਚ",
+            "(\\d+[.,]?\\d*) ਘੰਟੇ ਵਿੱਚ"
         ],
         "in \\1 minute": [
-            "(\\d+) ਮਿੰਟ ਵਿੱਚ",
-            "(\\d+) ਮਿੰਟਾਂ ਵਿੱਚ"
+            "(\\d+[.,]?\\d*) ਮਿੰਟ ਵਿੱਚ",
+            "(\\d+[.,]?\\d*) ਮਿੰਟਾਂ ਵਿੱਚ"
         ],
         "in \\1 month": [
-            "(\\d+) ਮਹੀਨਿਆਂ ਵਿੱਚ",
-            "(\\d+) ਮਹੀਨੇ ਵਿੱਚ"
+            "(\\d+[.,]?\\d*) ਮਹੀਨਿਆਂ ਵਿੱਚ",
+            "(\\d+[.,]?\\d*) ਮਹੀਨੇ ਵਿੱਚ"
         ],
         "in \\1 second": [
-            "(\\d+) ਸਕਿੰਟ ਵਿੱਚ",
-            "(\\d+) ਸਕਿੰਟਾਂ ਵਿੱਚ"
+            "(\\d+[.,]?\\d*) ਸਕਿੰਟ ਵਿੱਚ",
+            "(\\d+[.,]?\\d*) ਸਕਿੰਟਾਂ ਵਿੱਚ"
         ],
         "in \\1 week": [
-            "(\\d+) ਹਫ਼ਤਿਆਂ ਵਿੱਚ",
-            "(\\d+) ਹਫ਼ਤੇ ਵਿੱਚ"
+            "(\\d+[.,]?\\d*) ਹਫ਼ਤਿਆਂ ਵਿੱਚ",
+            "(\\d+[.,]?\\d*) ਹਫ਼ਤੇ ਵਿੱਚ"
         ],
         "in \\1 year": [
-            "(\\d+) ਸਾਲ ਵਿੱਚ",
-            "(\\d+) ਸਾਲਾਂ ਵਿੱਚ"
+            "(\\d+[.,]?\\d*) ਸਾਲ ਵਿੱਚ",
+            "(\\d+[.,]?\\d*) ਸਾਲਾਂ ਵਿੱਚ"
         ]
     },
     "locale_specific": {},
