@@ -198,9 +198,7 @@ class TestDateParser(BaseTestCase):
             param("[সেপ্টেম্বর] 04, 2014.", datetime(2014, 9, 4)),
             param("মঙ্গলবার জুলাই 22, 2014", datetime(2014, 7, 22)),
             param("শুক্রবার", datetime(2012, 11, 9)),
-            param(
-                "শুক্র, 12 ডিসেম্বর 2014 10:55:50", datetime(2014, 12, 12, 10, 55, 50)
-            ),
+            param("শুক্র, 12 ডিসেম্বর 2014 10:55:50", datetime(2014, 12, 12, 10, 55, 50)),
             param("1লা জানুয়ারী 2015", datetime(2015, 1, 1)),
             param("25শে মার্চ 1971", datetime(1971, 3, 25)),
             param("8ই মে 2002", datetime(2002, 5, 8)),
@@ -418,9 +416,7 @@ class TestDateParser(BaseTestCase):
             param("[সেপ্টেম্বর] 04, 2014.", datetime(2014, 9, 4)),
             param("মঙ্গলবার জুলাই 22, 2014", datetime(2014, 7, 22)),
             param("শুক্রবার", datetime(2012, 11, 9)),
-            param(
-                "শুক্র, 12 ডিসেম্বর 2014 10:55:50", datetime(2014, 12, 12, 10, 55, 50)
-            ),
+            param("শুক্র, 12 ডিসেম্বর 2014 10:55:50", datetime(2014, 12, 12, 10, 55, 50)),
             param("1লা জানুয়ারী 2015", datetime(2015, 1, 1)),
             param("25শে মার্চ 1971", datetime(1971, 3, 25)),
             param("8ই মে 2002", datetime(2002, 5, 8)),
@@ -1213,6 +1209,16 @@ class TestDateParser(BaseTestCase):
                 datetime(2021, 10, 19, 20, 0),
                 {"PREFER_DATES_FROM": "future"},
             ),
+            param(
+                "10pm EDT",
+                datetime(2021, 10, 20, 2, 0),
+                {"PREFER_DATES_FROM": "future"},
+            ),
+            param(
+                "8am AEDT",
+                datetime(2021, 10, 18, 21, 0),
+                {"PREFER_DATES_FROM": "past"},
+            ),
             param(
                 "11pm AEDT",
                 datetime(2021, 10, 19, 12, 0),
@@ -1223,6 +1229,16 @@ class TestDateParser(BaseTestCase):
                 datetime(2021, 10, 19, 20, 0),
                 {"PREFER_DATES_FROM": "future", "TIMEZONE": "EDT"},
             ),
+            param(
+                "10pm",
+                datetime(2021, 10, 20, 2, 0),
+                {"PREFER_DATES_FROM": "future", "TIMEZONE": "EDT"},
+            ),
+            param(
+                "8am",
+                datetime(2021, 10, 18, 21, 0),
+                {"PREFER_DATES_FROM": "past", "TIMEZONE": "AEDT"},
+            ),
             param(
                 "11pm",
                 datetime(2021, 10, 19, 12, 0),
@@ -1245,6 +1261,66 @@ class TestDateParser(BaseTestCase):
         self.then_date_was_parsed_by_date_parser()
         self.then_date_obj_exactly_is(expected)
 
+    @parameterized.expand(
+        [
+            param(
+                "2015",
+                prefer_day="current",
+                prefer_month="current",
+                today=datetime(2010, 2, 10),
+                expected=datetime(2015, 2, 10),
+            ),
+            param(
+                "2015",
+                prefer_day="last",
+                prefer_month="current",
+                today=datetime(2010, 2, 10),
+                expected=datetime(2015, 2, 28),
+            ),
+            param(
+                "2015",
+                prefer_day="first",
+                prefer_month="current",
+                today=datetime(2010, 2, 10),
+                expected=datetime(2015, 2, 1),
+            ),
+            param(
+                "2015",
+                prefer_day="current",
+                prefer_month="last",
+                today=datetime(2010, 2, 10),
+                expected=datetime(2015, 12, 10),
+            ),
+            param(
+                "2015",
+                prefer_day="last",
+                prefer_month="last",
+                today=datetime(2010, 2, 10),
+                expected=datetime(2015, 12, 31),
+            ),
+            param(
+                "2020",  # Leap year last day test
+                prefer_day="last",
+                prefer_month="current",
+                today=datetime(2010, 2, 10),
+                expected=datetime(2020, 2, 29),
+            ),
+        ]
+    )
+    def test_dates_with_no_day_or_month(
+        self, date_string, prefer_day, prefer_month, today=None, expected=None
+    ):
+        self.given_parser(
+            settings={
+                "PREFER_DAY_OF_MONTH": prefer_day,
+                "PREFER_MONTH_OF_YEAR": prefer_month,
+                "RELATIVE_BASE": today,
+            }
+        )
+        self.when_date_is_parsed(date_string)
+        self.then_date_was_parsed_by_date_parser()
+        self.then_date_obj_exactly_is(expected)
+
     def given_local_tz_offset(self, offset):
         self.add_patch(
             patch.object(
