@@ -1,3 +1,7 @@
+import pytest
+
+pytest.importorskip("fasttext")
+
 import unittest
 from datetime import datetime
 from unittest.mock import Mock
