@@ -1,5 +1,6 @@
 import datetime as dt
 from datetime import datetime, timedelta
+from unittest import SkipTest
 from unittest.mock import Mock, patch
 
 from parameterized import param, parameterized
@@ -18,9 +19,9 @@ from tests import BaseTestCase
 class TestTZPopping(BaseTestCase):
     def setUp(self):
         super().setUp()
-        self.initial_string = (
-            self.datetime_string
-        ) = self.timezone_offset = NotImplemented
+        self.initial_string = self.datetime_string = self.timezone_offset = (
+            NotImplemented
+        )
 
     @parameterized.expand(
         [
@@ -134,7 +135,10 @@ class TestLocalTZOffset(BaseTestCase):
         ]
     )
     def test_timezone_offset_calculation(self, utc, local, offset):
-        self.given_time(utc, local)
+        try:
+            self.given_time(utc, local)
+        except OverflowError:
+            raise SkipTest("Unsupported with 32-bit time_t")
         self.when_offset_popped_from_string()
         self.then_offset_is(offset)
 
@@ -153,8 +157,8 @@ class TestLocalTZOffset(BaseTestCase):
         datetime_cls = dateparser.timezone_parser.datetime
         if not isinstance(datetime_cls, Mock):
             datetime_cls = Mock(wraps=datetime)
-        utc_dt_obj = datetime.strptime(utc_dt_string, "%Y-%m-%d %H:%M").astimezone(
-            dt.timezone.utc
+        utc_dt_obj = datetime.strptime(utc_dt_string, "%Y-%m-%d %H:%M").replace(
+            tzinfo=dt.timezone.utc
         )
         local_dt_obj = datetime.strptime(local_dt_string, "%Y-%m-%d %H:%M")
 
